Generic Tornado Server
======================

**Author:** "Chris Ward" <cward@redhat.com>

**Sources:** https://github.com/kejbaly2/tornadohttp


Install
~~~~~~~

`pip install tornadohttp`

or 

`python setup.py install`

or 

`python setup.py develop`
